# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('catalogue', '0005_auto_20150604_1450'),
    ]

    operations = [
        migrations.CreateModel(
            name='OscarFeatured',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='cms_oscar_oscarfeatured', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('limit', models.PositiveIntegerField(default=6)),
                ('renderTemplate', models.CharField(default=b'cmsoscar/Featured.html', max_length=150, verbose_name=b'Featured Template', blank=True, choices=[(b'cmsoscar/Featured.html', 'Default'), (b'cms_oscar/TemplateShop.html', 'Template Shop')])),
                ('tag', models.IntegerField(default=None, null=True, blank=True)),
                ('catagory', models.ForeignKey(related_name='+', default=None, blank=True, to='catalogue.Category', null=True, on_delete=models.CASCADE)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='OscarLatest',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='cms_oscar_oscarlatest', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('limit', models.PositiveIntegerField(default=6)),
                ('renderTemplate', models.CharField(default=b'cmsoscar/Latest.html', max_length=150, verbose_name=b'Latest Template', blank=True, choices=[(b'cmsoscar/Latest.html', 'Default'), (b'cms_oscar/TemplateShop.html', 'Template Shop')])),
                ('tag', models.IntegerField(default=None, null=True, blank=True)),
                ('catagory', models.ForeignKey(related_name='+', default=None, blank=True, to='catalogue.Category', null=True, on_delete=models.CASCADE)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
